/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface IntegrationConnectorsManagedZoneConfig extends cdktf.TerraformMetaArguments {
    /**
    * Description of the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/integration_connectors_managed_zone#description IntegrationConnectorsManagedZone#description}
    */
    readonly description?: string;
    /**
    * DNS Name of the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/integration_connectors_managed_zone#dns IntegrationConnectorsManagedZone#dns}
    */
    readonly dns: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/integration_connectors_managed_zone#id IntegrationConnectorsManagedZone#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Resource labels to represent user provided metadata.
    *
    *
    * **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
    * Please refer to the field 'effective_labels' for all of the labels present on the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/integration_connectors_managed_zone#labels IntegrationConnectorsManagedZone#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * Name of Managed Zone needs to be created.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/integration_connectors_managed_zone#name IntegrationConnectorsManagedZone#name}
    */
    readonly name: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/integration_connectors_managed_zone#project IntegrationConnectorsManagedZone#project}
    */
    readonly project?: string;
    /**
    * The name of the Target Project.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/integration_connectors_managed_zone#target_project IntegrationConnectorsManagedZone#target_project}
    */
    readonly targetProject: string;
    /**
    * The name of the Target Project VPC Network.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/integration_connectors_managed_zone#target_vpc IntegrationConnectorsManagedZone#target_vpc}
    */
    readonly targetVpc: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/integration_connectors_managed_zone#timeouts IntegrationConnectorsManagedZone#timeouts}
    */
    readonly timeouts?: IntegrationConnectorsManagedZoneTimeouts;
}
export interface IntegrationConnectorsManagedZoneTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/integration_connectors_managed_zone#create IntegrationConnectorsManagedZone#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/integration_connectors_managed_zone#delete IntegrationConnectorsManagedZone#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/integration_connectors_managed_zone#update IntegrationConnectorsManagedZone#update}
    */
    readonly update?: string;
}
export declare function integrationConnectorsManagedZoneTimeoutsToTerraform(struct?: IntegrationConnectorsManagedZoneTimeouts | cdktf.IResolvable): any;
export declare function integrationConnectorsManagedZoneTimeoutsToHclTerraform(struct?: IntegrationConnectorsManagedZoneTimeouts | cdktf.IResolvable): any;
export declare class IntegrationConnectorsManagedZoneTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): IntegrationConnectorsManagedZoneTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: IntegrationConnectorsManagedZoneTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/integration_connectors_managed_zone google_integration_connectors_managed_zone}
*/
export declare class IntegrationConnectorsManagedZone extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_integration_connectors_managed_zone";
    /**
    * Generates CDKTF code for importing a IntegrationConnectorsManagedZone resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the IntegrationConnectorsManagedZone to import
    * @param importFromId The id of the existing IntegrationConnectorsManagedZone that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/integration_connectors_managed_zone#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the IntegrationConnectorsManagedZone to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/integration_connectors_managed_zone google_integration_connectors_managed_zone} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options IntegrationConnectorsManagedZoneConfig
    */
    constructor(scope: Construct, id: string, config: IntegrationConnectorsManagedZoneConfig);
    get createTime(): string;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _dns?;
    get dns(): string;
    set dns(value: string);
    get dnsInput(): string | undefined;
    private _effectiveLabels;
    get effectiveLabels(): cdktf.StringMap;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _targetProject?;
    get targetProject(): string;
    set targetProject(value: string);
    get targetProjectInput(): string | undefined;
    private _targetVpc?;
    get targetVpc(): string;
    set targetVpc(value: string);
    get targetVpcInput(): string | undefined;
    private _terraformLabels;
    get terraformLabels(): cdktf.StringMap;
    get updateTime(): string;
    private _timeouts;
    get timeouts(): IntegrationConnectorsManagedZoneTimeoutsOutputReference;
    putTimeouts(value: IntegrationConnectorsManagedZoneTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | IntegrationConnectorsManagedZoneTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
