/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface SccProjectCustomModuleConfig extends cdktf.TerraformMetaArguments {
    /**
    * The display name of the Security Health Analytics custom module. This
    * display name becomes the finding category for all findings that are
    * returned by this custom module. The display name must be between 1 and
    * 128 characters, start with a lowercase letter, and contain alphanumeric
    * characters or underscores only.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/scc_project_custom_module#display_name SccProjectCustomModule#display_name}
    */
    readonly displayName: string;
    /**
    * The enablement state of the custom module. Possible values: ["ENABLED", "DISABLED"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/scc_project_custom_module#enablement_state SccProjectCustomModule#enablement_state}
    */
    readonly enablementState: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/scc_project_custom_module#id SccProjectCustomModule#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/scc_project_custom_module#project SccProjectCustomModule#project}
    */
    readonly project?: string;
    /**
    * custom_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/scc_project_custom_module#custom_config SccProjectCustomModule#custom_config}
    */
    readonly customConfig: SccProjectCustomModuleCustomConfig;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/scc_project_custom_module#timeouts SccProjectCustomModule#timeouts}
    */
    readonly timeouts?: SccProjectCustomModuleTimeouts;
}
export interface SccProjectCustomModuleCustomConfigCustomOutputPropertiesValueExpression {
    /**
    * Description of the expression. This is a longer text which describes the
    * expression, e.g. when hovered over it in a UI.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/scc_project_custom_module#description SccProjectCustomModule#description}
    */
    readonly description?: string;
    /**
    * Textual representation of an expression in Common Expression Language syntax.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/scc_project_custom_module#expression SccProjectCustomModule#expression}
    */
    readonly expression: string;
    /**
    * String indicating the location of the expression for error reporting, e.g. a
    * file name and a position in the file.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/scc_project_custom_module#location SccProjectCustomModule#location}
    */
    readonly location?: string;
    /**
    * Title for the expression, i.e. a short string describing its purpose. This can
    * be used e.g. in UIs which allow to enter the expression.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/scc_project_custom_module#title SccProjectCustomModule#title}
    */
    readonly title?: string;
}
export declare function sccProjectCustomModuleCustomConfigCustomOutputPropertiesValueExpressionToTerraform(struct?: SccProjectCustomModuleCustomConfigCustomOutputPropertiesValueExpressionOutputReference | SccProjectCustomModuleCustomConfigCustomOutputPropertiesValueExpression): any;
export declare function sccProjectCustomModuleCustomConfigCustomOutputPropertiesValueExpressionToHclTerraform(struct?: SccProjectCustomModuleCustomConfigCustomOutputPropertiesValueExpressionOutputReference | SccProjectCustomModuleCustomConfigCustomOutputPropertiesValueExpression): any;
export declare class SccProjectCustomModuleCustomConfigCustomOutputPropertiesValueExpressionOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): SccProjectCustomModuleCustomConfigCustomOutputPropertiesValueExpression | undefined;
    set internalValue(value: SccProjectCustomModuleCustomConfigCustomOutputPropertiesValueExpression | undefined);
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _expression?;
    get expression(): string;
    set expression(value: string);
    get expressionInput(): string | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    resetLocation(): void;
    get locationInput(): string | undefined;
    private _title?;
    get title(): string;
    set title(value: string);
    resetTitle(): void;
    get titleInput(): string | undefined;
}
export interface SccProjectCustomModuleCustomConfigCustomOutputProperties {
    /**
    * Name of the property for the custom output.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/scc_project_custom_module#name SccProjectCustomModule#name}
    */
    readonly name?: string;
    /**
    * value_expression block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/scc_project_custom_module#value_expression SccProjectCustomModule#value_expression}
    */
    readonly valueExpression?: SccProjectCustomModuleCustomConfigCustomOutputPropertiesValueExpression;
}
export declare function sccProjectCustomModuleCustomConfigCustomOutputPropertiesToTerraform(struct?: SccProjectCustomModuleCustomConfigCustomOutputProperties | cdktf.IResolvable): any;
export declare function sccProjectCustomModuleCustomConfigCustomOutputPropertiesToHclTerraform(struct?: SccProjectCustomModuleCustomConfigCustomOutputProperties | cdktf.IResolvable): any;
export declare class SccProjectCustomModuleCustomConfigCustomOutputPropertiesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): SccProjectCustomModuleCustomConfigCustomOutputProperties | cdktf.IResolvable | undefined;
    set internalValue(value: SccProjectCustomModuleCustomConfigCustomOutputProperties | cdktf.IResolvable | undefined);
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    private _valueExpression;
    get valueExpression(): SccProjectCustomModuleCustomConfigCustomOutputPropertiesValueExpressionOutputReference;
    putValueExpression(value: SccProjectCustomModuleCustomConfigCustomOutputPropertiesValueExpression): void;
    resetValueExpression(): void;
    get valueExpressionInput(): SccProjectCustomModuleCustomConfigCustomOutputPropertiesValueExpression | undefined;
}
export declare class SccProjectCustomModuleCustomConfigCustomOutputPropertiesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: SccProjectCustomModuleCustomConfigCustomOutputProperties[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): SccProjectCustomModuleCustomConfigCustomOutputPropertiesOutputReference;
}
export interface SccProjectCustomModuleCustomConfigCustomOutput {
    /**
    * properties block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/scc_project_custom_module#properties SccProjectCustomModule#properties}
    */
    readonly properties?: SccProjectCustomModuleCustomConfigCustomOutputProperties[] | cdktf.IResolvable;
}
export declare function sccProjectCustomModuleCustomConfigCustomOutputToTerraform(struct?: SccProjectCustomModuleCustomConfigCustomOutputOutputReference | SccProjectCustomModuleCustomConfigCustomOutput): any;
export declare function sccProjectCustomModuleCustomConfigCustomOutputToHclTerraform(struct?: SccProjectCustomModuleCustomConfigCustomOutputOutputReference | SccProjectCustomModuleCustomConfigCustomOutput): any;
export declare class SccProjectCustomModuleCustomConfigCustomOutputOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): SccProjectCustomModuleCustomConfigCustomOutput | undefined;
    set internalValue(value: SccProjectCustomModuleCustomConfigCustomOutput | undefined);
    private _properties;
    get properties(): SccProjectCustomModuleCustomConfigCustomOutputPropertiesList;
    putProperties(value: SccProjectCustomModuleCustomConfigCustomOutputProperties[] | cdktf.IResolvable): void;
    resetProperties(): void;
    get propertiesInput(): cdktf.IResolvable | SccProjectCustomModuleCustomConfigCustomOutputProperties[] | undefined;
}
export interface SccProjectCustomModuleCustomConfigPredicate {
    /**
    * Description of the expression. This is a longer text which describes the
    * expression, e.g. when hovered over it in a UI.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/scc_project_custom_module#description SccProjectCustomModule#description}
    */
    readonly description?: string;
    /**
    * Textual representation of an expression in Common Expression Language syntax.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/scc_project_custom_module#expression SccProjectCustomModule#expression}
    */
    readonly expression: string;
    /**
    * String indicating the location of the expression for error reporting, e.g. a
    * file name and a position in the file.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/scc_project_custom_module#location SccProjectCustomModule#location}
    */
    readonly location?: string;
    /**
    * Title for the expression, i.e. a short string describing its purpose. This can
    * be used e.g. in UIs which allow to enter the expression.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/scc_project_custom_module#title SccProjectCustomModule#title}
    */
    readonly title?: string;
}
export declare function sccProjectCustomModuleCustomConfigPredicateToTerraform(struct?: SccProjectCustomModuleCustomConfigPredicateOutputReference | SccProjectCustomModuleCustomConfigPredicate): any;
export declare function sccProjectCustomModuleCustomConfigPredicateToHclTerraform(struct?: SccProjectCustomModuleCustomConfigPredicateOutputReference | SccProjectCustomModuleCustomConfigPredicate): any;
export declare class SccProjectCustomModuleCustomConfigPredicateOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): SccProjectCustomModuleCustomConfigPredicate | undefined;
    set internalValue(value: SccProjectCustomModuleCustomConfigPredicate | undefined);
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _expression?;
    get expression(): string;
    set expression(value: string);
    get expressionInput(): string | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    resetLocation(): void;
    get locationInput(): string | undefined;
    private _title?;
    get title(): string;
    set title(value: string);
    resetTitle(): void;
    get titleInput(): string | undefined;
}
export interface SccProjectCustomModuleCustomConfigResourceSelector {
    /**
    * The resource types to run the detector on.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/scc_project_custom_module#resource_types SccProjectCustomModule#resource_types}
    */
    readonly resourceTypes: string[];
}
export declare function sccProjectCustomModuleCustomConfigResourceSelectorToTerraform(struct?: SccProjectCustomModuleCustomConfigResourceSelectorOutputReference | SccProjectCustomModuleCustomConfigResourceSelector): any;
export declare function sccProjectCustomModuleCustomConfigResourceSelectorToHclTerraform(struct?: SccProjectCustomModuleCustomConfigResourceSelectorOutputReference | SccProjectCustomModuleCustomConfigResourceSelector): any;
export declare class SccProjectCustomModuleCustomConfigResourceSelectorOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): SccProjectCustomModuleCustomConfigResourceSelector | undefined;
    set internalValue(value: SccProjectCustomModuleCustomConfigResourceSelector | undefined);
    private _resourceTypes?;
    get resourceTypes(): string[];
    set resourceTypes(value: string[]);
    get resourceTypesInput(): string[] | undefined;
}
export interface SccProjectCustomModuleCustomConfig {
    /**
    * Text that describes the vulnerability or misconfiguration that the custom
    * module detects. This explanation is returned with each finding instance to
    * help investigators understand the detected issue. The text must be enclosed in quotation marks.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/scc_project_custom_module#description SccProjectCustomModule#description}
    */
    readonly description?: string;
    /**
    * An explanation of the recommended steps that security teams can take to resolve
    * the detected issue. This explanation is returned with each finding generated by
    * this module in the nextSteps property of the finding JSON.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/scc_project_custom_module#recommendation SccProjectCustomModule#recommendation}
    */
    readonly recommendation: string;
    /**
    * The severity to assign to findings generated by the module. Possible values: ["CRITICAL", "HIGH", "MEDIUM", "LOW"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/scc_project_custom_module#severity SccProjectCustomModule#severity}
    */
    readonly severity: string;
    /**
    * custom_output block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/scc_project_custom_module#custom_output SccProjectCustomModule#custom_output}
    */
    readonly customOutput?: SccProjectCustomModuleCustomConfigCustomOutput;
    /**
    * predicate block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/scc_project_custom_module#predicate SccProjectCustomModule#predicate}
    */
    readonly predicate: SccProjectCustomModuleCustomConfigPredicate;
    /**
    * resource_selector block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/scc_project_custom_module#resource_selector SccProjectCustomModule#resource_selector}
    */
    readonly resourceSelector: SccProjectCustomModuleCustomConfigResourceSelector;
}
export declare function sccProjectCustomModuleCustomConfigToTerraform(struct?: SccProjectCustomModuleCustomConfigOutputReference | SccProjectCustomModuleCustomConfig): any;
export declare function sccProjectCustomModuleCustomConfigToHclTerraform(struct?: SccProjectCustomModuleCustomConfigOutputReference | SccProjectCustomModuleCustomConfig): any;
export declare class SccProjectCustomModuleCustomConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): SccProjectCustomModuleCustomConfig | undefined;
    set internalValue(value: SccProjectCustomModuleCustomConfig | undefined);
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _recommendation?;
    get recommendation(): string;
    set recommendation(value: string);
    get recommendationInput(): string | undefined;
    private _severity?;
    get severity(): string;
    set severity(value: string);
    get severityInput(): string | undefined;
    private _customOutput;
    get customOutput(): SccProjectCustomModuleCustomConfigCustomOutputOutputReference;
    putCustomOutput(value: SccProjectCustomModuleCustomConfigCustomOutput): void;
    resetCustomOutput(): void;
    get customOutputInput(): SccProjectCustomModuleCustomConfigCustomOutput | undefined;
    private _predicate;
    get predicate(): SccProjectCustomModuleCustomConfigPredicateOutputReference;
    putPredicate(value: SccProjectCustomModuleCustomConfigPredicate): void;
    get predicateInput(): SccProjectCustomModuleCustomConfigPredicate | undefined;
    private _resourceSelector;
    get resourceSelector(): SccProjectCustomModuleCustomConfigResourceSelectorOutputReference;
    putResourceSelector(value: SccProjectCustomModuleCustomConfigResourceSelector): void;
    get resourceSelectorInput(): SccProjectCustomModuleCustomConfigResourceSelector | undefined;
}
export interface SccProjectCustomModuleTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/scc_project_custom_module#create SccProjectCustomModule#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/scc_project_custom_module#delete SccProjectCustomModule#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/scc_project_custom_module#update SccProjectCustomModule#update}
    */
    readonly update?: string;
}
export declare function sccProjectCustomModuleTimeoutsToTerraform(struct?: SccProjectCustomModuleTimeouts | cdktf.IResolvable): any;
export declare function sccProjectCustomModuleTimeoutsToHclTerraform(struct?: SccProjectCustomModuleTimeouts | cdktf.IResolvable): any;
export declare class SccProjectCustomModuleTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): SccProjectCustomModuleTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: SccProjectCustomModuleTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/scc_project_custom_module google_scc_project_custom_module}
*/
export declare class SccProjectCustomModule extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_scc_project_custom_module";
    /**
    * Generates CDKTF code for importing a SccProjectCustomModule resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the SccProjectCustomModule to import
    * @param importFromId The id of the existing SccProjectCustomModule that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/scc_project_custom_module#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the SccProjectCustomModule to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/scc_project_custom_module google_scc_project_custom_module} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options SccProjectCustomModuleConfig
    */
    constructor(scope: Construct, id: string, config: SccProjectCustomModuleConfig);
    get ancestorModule(): string;
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    get displayNameInput(): string | undefined;
    private _enablementState?;
    get enablementState(): string;
    set enablementState(value: string);
    get enablementStateInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get lastEditor(): string;
    get name(): string;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    get updateTime(): string;
    private _customConfig;
    get customConfig(): SccProjectCustomModuleCustomConfigOutputReference;
    putCustomConfig(value: SccProjectCustomModuleCustomConfig): void;
    get customConfigInput(): SccProjectCustomModuleCustomConfig | undefined;
    private _timeouts;
    get timeouts(): SccProjectCustomModuleTimeoutsOutputReference;
    putTimeouts(value: SccProjectCustomModuleTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | SccProjectCustomModuleTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
