/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface SccV2OrganizationSourceConfig extends cdktf.TerraformMetaArguments {
    /**
    * The description of the source (max of 1024 characters).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/scc_v2_organization_source#description SccV2OrganizationSource#description}
    */
    readonly description?: string;
    /**
    * The source’s display name. A source’s display name must be unique
    * amongst its siblings, for example, two sources with the same parent
    * can't share the same display name. The display name must start and end
    * with a letter or digit, may contain letters, digits, spaces, hyphens,
    * and underscores, and can be no longer than 32 characters.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/scc_v2_organization_source#display_name SccV2OrganizationSource#display_name}
    */
    readonly displayName: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/scc_v2_organization_source#id SccV2OrganizationSource#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The organization whose Cloud Security Command Center the Source
    * lives in.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/scc_v2_organization_source#organization SccV2OrganizationSource#organization}
    */
    readonly organization: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/scc_v2_organization_source#timeouts SccV2OrganizationSource#timeouts}
    */
    readonly timeouts?: SccV2OrganizationSourceTimeouts;
}
export interface SccV2OrganizationSourceTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/scc_v2_organization_source#create SccV2OrganizationSource#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/scc_v2_organization_source#delete SccV2OrganizationSource#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/scc_v2_organization_source#update SccV2OrganizationSource#update}
    */
    readonly update?: string;
}
export declare function sccV2OrganizationSourceTimeoutsToTerraform(struct?: SccV2OrganizationSourceTimeouts | cdktf.IResolvable): any;
export declare function sccV2OrganizationSourceTimeoutsToHclTerraform(struct?: SccV2OrganizationSourceTimeouts | cdktf.IResolvable): any;
export declare class SccV2OrganizationSourceTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): SccV2OrganizationSourceTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: SccV2OrganizationSourceTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/scc_v2_organization_source google_scc_v2_organization_source}
*/
export declare class SccV2OrganizationSource extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_scc_v2_organization_source";
    /**
    * Generates CDKTF code for importing a SccV2OrganizationSource resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the SccV2OrganizationSource to import
    * @param importFromId The id of the existing SccV2OrganizationSource that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/scc_v2_organization_source#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the SccV2OrganizationSource to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/scc_v2_organization_source google_scc_v2_organization_source} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options SccV2OrganizationSourceConfig
    */
    constructor(scope: Construct, id: string, config: SccV2OrganizationSourceConfig);
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    get displayNameInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get name(): string;
    private _organization?;
    get organization(): string;
    set organization(value: string);
    get organizationInput(): string | undefined;
    private _timeouts;
    get timeouts(): SccV2OrganizationSourceTimeoutsOutputReference;
    putTimeouts(value: SccV2OrganizationSourceTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | SccV2OrganizationSourceTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
