/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface SecretManagerSecretIamBindingConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/secret_manager_secret_iam_binding#id SecretManagerSecretIamBinding#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/secret_manager_secret_iam_binding#members SecretManagerSecretIamBinding#members}
    */
    readonly members: string[];
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/secret_manager_secret_iam_binding#project SecretManagerSecretIamBinding#project}
    */
    readonly project?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/secret_manager_secret_iam_binding#role SecretManagerSecretIamBinding#role}
    */
    readonly role: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/secret_manager_secret_iam_binding#secret_id SecretManagerSecretIamBinding#secret_id}
    */
    readonly secretId: string;
    /**
    * condition block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/secret_manager_secret_iam_binding#condition SecretManagerSecretIamBinding#condition}
    */
    readonly condition?: SecretManagerSecretIamBindingCondition;
}
export interface SecretManagerSecretIamBindingCondition {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/secret_manager_secret_iam_binding#description SecretManagerSecretIamBinding#description}
    */
    readonly description?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/secret_manager_secret_iam_binding#expression SecretManagerSecretIamBinding#expression}
    */
    readonly expression: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/secret_manager_secret_iam_binding#title SecretManagerSecretIamBinding#title}
    */
    readonly title: string;
}
export declare function secretManagerSecretIamBindingConditionToTerraform(struct?: SecretManagerSecretIamBindingConditionOutputReference | SecretManagerSecretIamBindingCondition): any;
export declare function secretManagerSecretIamBindingConditionToHclTerraform(struct?: SecretManagerSecretIamBindingConditionOutputReference | SecretManagerSecretIamBindingCondition): any;
export declare class SecretManagerSecretIamBindingConditionOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): SecretManagerSecretIamBindingCondition | undefined;
    set internalValue(value: SecretManagerSecretIamBindingCondition | undefined);
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _expression?;
    get expression(): string;
    set expression(value: string);
    get expressionInput(): string | undefined;
    private _title?;
    get title(): string;
    set title(value: string);
    get titleInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/secret_manager_secret_iam_binding google_secret_manager_secret_iam_binding}
*/
export declare class SecretManagerSecretIamBinding extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_secret_manager_secret_iam_binding";
    /**
    * Generates CDKTF code for importing a SecretManagerSecretIamBinding resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the SecretManagerSecretIamBinding to import
    * @param importFromId The id of the existing SecretManagerSecretIamBinding that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/secret_manager_secret_iam_binding#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the SecretManagerSecretIamBinding to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/secret_manager_secret_iam_binding google_secret_manager_secret_iam_binding} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options SecretManagerSecretIamBindingConfig
    */
    constructor(scope: Construct, id: string, config: SecretManagerSecretIamBindingConfig);
    get etag(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _members?;
    get members(): string[];
    set members(value: string[]);
    get membersInput(): string[] | undefined;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _role?;
    get role(): string;
    set role(value: string);
    get roleInput(): string | undefined;
    private _secretId?;
    get secretId(): string;
    set secretId(value: string);
    get secretIdInput(): string | undefined;
    private _condition;
    get condition(): SecretManagerSecretIamBindingConditionOutputReference;
    putCondition(value: SecretManagerSecretIamBindingCondition): void;
    resetCondition(): void;
    get conditionInput(): SecretManagerSecretIamBindingCondition | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
