/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface VmwareengineExternalAccessRuleConfig extends cdktf.TerraformMetaArguments {
    /**
    * The action that the external access rule performs. Possible values: ["ALLOW", "DENY"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/vmwareengine_external_access_rule#action VmwareengineExternalAccessRule#action}
    */
    readonly action: string;
    /**
    * User-provided description for the external access rule.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/vmwareengine_external_access_rule#description VmwareengineExternalAccessRule#description}
    */
    readonly description?: string;
    /**
    * A list of destination ports to which the external access rule applies.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/vmwareengine_external_access_rule#destination_ports VmwareengineExternalAccessRule#destination_ports}
    */
    readonly destinationPorts: string[];
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/vmwareengine_external_access_rule#id VmwareengineExternalAccessRule#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The IP protocol to which the external access rule applies.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/vmwareengine_external_access_rule#ip_protocol VmwareengineExternalAccessRule#ip_protocol}
    */
    readonly ipProtocol: string;
    /**
    * The ID of the external access rule.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/vmwareengine_external_access_rule#name VmwareengineExternalAccessRule#name}
    */
    readonly name: string;
    /**
    * The resource name of the network policy.
    * Resource names are schemeless URIs that follow the conventions in https://cloud.google.com/apis/design/resource_names.
    * For example: projects/my-project/locations/us-west1-a/networkPolicies/my-policy
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/vmwareengine_external_access_rule#parent VmwareengineExternalAccessRule#parent}
    */
    readonly parent: string;
    /**
    * External access rule priority, which determines the external access rule to use when multiple rules apply.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/vmwareengine_external_access_rule#priority VmwareengineExternalAccessRule#priority}
    */
    readonly priority: number;
    /**
    * A list of source ports to which the external access rule applies.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/vmwareengine_external_access_rule#source_ports VmwareengineExternalAccessRule#source_ports}
    */
    readonly sourcePorts: string[];
    /**
    * destination_ip_ranges block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/vmwareengine_external_access_rule#destination_ip_ranges VmwareengineExternalAccessRule#destination_ip_ranges}
    */
    readonly destinationIpRanges: VmwareengineExternalAccessRuleDestinationIpRanges[] | cdktf.IResolvable;
    /**
    * source_ip_ranges block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/vmwareengine_external_access_rule#source_ip_ranges VmwareengineExternalAccessRule#source_ip_ranges}
    */
    readonly sourceIpRanges: VmwareengineExternalAccessRuleSourceIpRanges[] | cdktf.IResolvable;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/vmwareengine_external_access_rule#timeouts VmwareengineExternalAccessRule#timeouts}
    */
    readonly timeouts?: VmwareengineExternalAccessRuleTimeouts;
}
export interface VmwareengineExternalAccessRuleDestinationIpRanges {
    /**
    * The name of an 'ExternalAddress' resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/vmwareengine_external_access_rule#external_address VmwareengineExternalAccessRule#external_address}
    */
    readonly externalAddress?: string;
    /**
    * An IP address range in the CIDR format.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/vmwareengine_external_access_rule#ip_address_range VmwareengineExternalAccessRule#ip_address_range}
    */
    readonly ipAddressRange?: string;
}
export declare function vmwareengineExternalAccessRuleDestinationIpRangesToTerraform(struct?: VmwareengineExternalAccessRuleDestinationIpRanges | cdktf.IResolvable): any;
export declare function vmwareengineExternalAccessRuleDestinationIpRangesToHclTerraform(struct?: VmwareengineExternalAccessRuleDestinationIpRanges | cdktf.IResolvable): any;
export declare class VmwareengineExternalAccessRuleDestinationIpRangesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): VmwareengineExternalAccessRuleDestinationIpRanges | cdktf.IResolvable | undefined;
    set internalValue(value: VmwareengineExternalAccessRuleDestinationIpRanges | cdktf.IResolvable | undefined);
    private _externalAddress?;
    get externalAddress(): string;
    set externalAddress(value: string);
    resetExternalAddress(): void;
    get externalAddressInput(): string | undefined;
    private _ipAddressRange?;
    get ipAddressRange(): string;
    set ipAddressRange(value: string);
    resetIpAddressRange(): void;
    get ipAddressRangeInput(): string | undefined;
}
export declare class VmwareengineExternalAccessRuleDestinationIpRangesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: VmwareengineExternalAccessRuleDestinationIpRanges[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): VmwareengineExternalAccessRuleDestinationIpRangesOutputReference;
}
export interface VmwareengineExternalAccessRuleSourceIpRanges {
    /**
    * A single IP address.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/vmwareengine_external_access_rule#ip_address VmwareengineExternalAccessRule#ip_address}
    */
    readonly ipAddress?: string;
    /**
    * An IP address range in the CIDR format.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/vmwareengine_external_access_rule#ip_address_range VmwareengineExternalAccessRule#ip_address_range}
    */
    readonly ipAddressRange?: string;
}
export declare function vmwareengineExternalAccessRuleSourceIpRangesToTerraform(struct?: VmwareengineExternalAccessRuleSourceIpRanges | cdktf.IResolvable): any;
export declare function vmwareengineExternalAccessRuleSourceIpRangesToHclTerraform(struct?: VmwareengineExternalAccessRuleSourceIpRanges | cdktf.IResolvable): any;
export declare class VmwareengineExternalAccessRuleSourceIpRangesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): VmwareengineExternalAccessRuleSourceIpRanges | cdktf.IResolvable | undefined;
    set internalValue(value: VmwareengineExternalAccessRuleSourceIpRanges | cdktf.IResolvable | undefined);
    private _ipAddress?;
    get ipAddress(): string;
    set ipAddress(value: string);
    resetIpAddress(): void;
    get ipAddressInput(): string | undefined;
    private _ipAddressRange?;
    get ipAddressRange(): string;
    set ipAddressRange(value: string);
    resetIpAddressRange(): void;
    get ipAddressRangeInput(): string | undefined;
}
export declare class VmwareengineExternalAccessRuleSourceIpRangesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: VmwareengineExternalAccessRuleSourceIpRanges[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): VmwareengineExternalAccessRuleSourceIpRangesOutputReference;
}
export interface VmwareengineExternalAccessRuleTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/vmwareengine_external_access_rule#create VmwareengineExternalAccessRule#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/vmwareengine_external_access_rule#delete VmwareengineExternalAccessRule#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/vmwareengine_external_access_rule#update VmwareengineExternalAccessRule#update}
    */
    readonly update?: string;
}
export declare function vmwareengineExternalAccessRuleTimeoutsToTerraform(struct?: VmwareengineExternalAccessRuleTimeouts | cdktf.IResolvable): any;
export declare function vmwareengineExternalAccessRuleTimeoutsToHclTerraform(struct?: VmwareengineExternalAccessRuleTimeouts | cdktf.IResolvable): any;
export declare class VmwareengineExternalAccessRuleTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): VmwareengineExternalAccessRuleTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: VmwareengineExternalAccessRuleTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/vmwareengine_external_access_rule google_vmwareengine_external_access_rule}
*/
export declare class VmwareengineExternalAccessRule extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_vmwareengine_external_access_rule";
    /**
    * Generates CDKTF code for importing a VmwareengineExternalAccessRule resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the VmwareengineExternalAccessRule to import
    * @param importFromId The id of the existing VmwareengineExternalAccessRule that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/vmwareengine_external_access_rule#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the VmwareengineExternalAccessRule to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google/6.2.0/docs/resources/vmwareengine_external_access_rule google_vmwareengine_external_access_rule} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options VmwareengineExternalAccessRuleConfig
    */
    constructor(scope: Construct, id: string, config: VmwareengineExternalAccessRuleConfig);
    private _action?;
    get action(): string;
    set action(value: string);
    get actionInput(): string | undefined;
    get createTime(): string;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _destinationPorts?;
    get destinationPorts(): string[];
    set destinationPorts(value: string[]);
    get destinationPortsInput(): string[] | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _ipProtocol?;
    get ipProtocol(): string;
    set ipProtocol(value: string);
    get ipProtocolInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _parent?;
    get parent(): string;
    set parent(value: string);
    get parentInput(): string | undefined;
    private _priority?;
    get priority(): number;
    set priority(value: number);
    get priorityInput(): number | undefined;
    private _sourcePorts?;
    get sourcePorts(): string[];
    set sourcePorts(value: string[]);
    get sourcePortsInput(): string[] | undefined;
    get state(): string;
    get uid(): string;
    get updateTime(): string;
    private _destinationIpRanges;
    get destinationIpRanges(): VmwareengineExternalAccessRuleDestinationIpRangesList;
    putDestinationIpRanges(value: VmwareengineExternalAccessRuleDestinationIpRanges[] | cdktf.IResolvable): void;
    get destinationIpRangesInput(): cdktf.IResolvable | VmwareengineExternalAccessRuleDestinationIpRanges[] | undefined;
    private _sourceIpRanges;
    get sourceIpRanges(): VmwareengineExternalAccessRuleSourceIpRangesList;
    putSourceIpRanges(value: VmwareengineExternalAccessRuleSourceIpRanges[] | cdktf.IResolvable): void;
    get sourceIpRangesInput(): cdktf.IResolvable | VmwareengineExternalAccessRuleSourceIpRanges[] | undefined;
    private _timeouts;
    get timeouts(): VmwareengineExternalAccessRuleTimeoutsOutputReference;
    putTimeouts(value: VmwareengineExternalAccessRuleTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | VmwareengineExternalAccessRuleTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
